@@ -1,5 +1,6 @@
 /*
  *  Copyright (C) 2010 Felix Geyer <debfx@fobos.de>
+ *  Copyright (C) 2017 KeePassXC Team <team@keepassxc.org>
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,15 +19,17 @@
 #ifndef KEEPASSX_TESTGROUP_H
 #define KEEPASSX_TESTGROUP_H
 
-#include <QObject>
 #include "core/Database.h"
+#include <QObject>
 
 class TestGroup : public QObject
 {
     Q_OBJECT
 
-private Q_SLOTS:
+private slots:
     void initTestCase();
+    void init();
+    void cleanup();
     void testParenting();
     void testSignals();
     void testEntries();
@@ -34,13 +37,18 @@ private Q_SLOTS:
     void testCopyCustomIcon();
     void testClone();
     void testCopyCustomIcons();
-    void testMerge();
-    void testMergeConflict();
-    void testMergeDatabase();
-    void testMergeConflictKeepBoth();
-
-private:
-    Database* createMergeTestDatabase();
+    void testFindEntry();
+    void testFindGroupByPath();
+    void testPrint();
+    void testLocate();
+    void testAddEntryWithPath();
+    void testIsRecycled();
+    void testCopyDataFrom();
+    void testEquals();
+    void testChildrenSort();
+    void testHierarchy();
+    void testApplyGroupIconRecursively();
+    void testUsernamesRecursive();
 };
 
 #endif // KEEPASSX_TESTGROUP_H
